## Arches for Science 2.0.4 Release Notes


### Bug Fixes and Enhancements

- Add project and django request logging [#1611] (https://github.com/archesproject/arches-for-science/pull/1611)
- Remove extra element under observation title in project report workflow's select files step [#1613](https://github.com/archesproject/arches-for-science/issues/1613)
- Update resource models in package to include export configs by default [#1615](https://github.com/archesproject/arches-for-science/pull/1615)


### Dependency changes:

```
Python:
    Upgraded: arches: 7.6.10
JavaScript:
    Upgraded:
        None
```

### Breaking Changes
Due to changes in how projects and apps are configured in the final release of Arches 7.6, there are significant project alterations necessary to migrate from Arches for Science 1.1 to Arches for Science 2.0.

### Upgrading Arches for Science 
1. Start by upgrading your project to run using [Arches 7.6](https://github.com/archesproject/arches/blob/dev/7.6.x/releases/7.6.0.md#upgrading-arches). 

2. Update arches-for-science in your project's package.json file:
    ```
    "arches_for_science": "archesproject/arches-for-science#dev/2.0.x"
    ```

3. Add arches_for_science to your project's dependencies in your pyproject.toml file:
    ```
    "arches_for_science>=2.0.4,<2.1.0"
    ```

4. Upgrade to Arches for Science 2.0.4
    ```
    pip install --upgrade arches_for_science==2.0.4
    ```


